@@ -148,13 +148,17 @@ class RuleInterpreter:
             logger.debug('Number of Snapshot Documents: %s', len(docs))
             if docs and len(docs):
                 doc = docs[0]['json']
-                self.snapshots.append({
+                snapshot = {
                     'id': docs[0]['snapshotId'],
-                    'path': docs[0]['path'],
                     'structure': docs[0]['structure'],
                     'reference': docs[0]['reference'],
                     'source': docs[0]['source']
-                })
+                }
+                if 'paths' in docs[0]:
+                    snapshot['paths'] = docs[0]['paths']
+                else:
+                    snapshot['path'] = docs[0]['path']
+                self.snapshots.append(snapshot)
         else:
             json_dir = '%s%s' % (get_test_json_dir(), self.kwargs['container'])
             if exists_dir(json_dir):
@@ -163,20 +167,16 @@ class RuleInterpreter:
                     json_data = json_from_file(fname)
                     if json_data and 'json' in json_data:
                         doc = json_data['json']
-                        # self.snapshots.append({
-                        #     'id': json_data['snapshotId'],
-                        #     'path': json_data['path'],
-                        #     'structure': json_data['structure'],
-                        #     'reference': json_data['reference'],
-                        #     'source': json_data['source']
-                        # })
                         snapshot_val = {
                             'id': json_data['snapshotId'],
-                            'path': json_data['path'],
                             'structure': json_data['structure'],
                             'reference': json_data['reference'],
                             'source': json_data['source']
                         }
+                        if 'paths' in json_data:
+                            snapshot_val['paths'] = json_data['paths']
+                        else:
+                            snapshot_val['path'] = json_data['path']
                         singletest = get_from_currentdata(SINGLETEST)
                         if singletest:
                             snapshot_val['json'] = doc
