@@ -66,9 +66,14 @@ def get_snapshot_id_to_collection_dict(snapshot_file, container, dbname, filesys
 
 def run_validation_test(version, container, dbname, collection_data, testcase):
     comparator = Comparator(version, container, dbname, collection_data, testcase)
-    result_val = comparator.validate()
-    result_val.update(testcase)
-    return result_val
+    results = comparator.validate()
+    if isinstance(results, list):
+        for result in results:
+            result.update(testcase)
+        return results
+    else:
+        results.update(testcase)
+        return[results]
 
 
 def run_file_validation_tests(test_file, container, filesystem=True, snapshot_status=None):
@@ -120,6 +125,7 @@ def run_json_validation_tests(test_json_data, container, filesystem=True, snapsh
         return resultset
     if not snapshot_status:
         snapshot_status = {}
+    logger.info("Valid Test JSON data")
     logger.debug(json.dumps(test_json_data, indent=2))
     testsets = get_field_value(test_json_data, 'testSet')
     if not testsets or not isinstance(testsets, list):
@@ -140,10 +146,11 @@ def run_json_validation_tests(test_json_data, container, filesystem=True, snapsh
             logger.info("No testcases in testSet!...")
             continue
         for testcase in testset['cases']:
-            testcase['dirpath'] = dirpath
-            result_val = run_validation_test(version, container, dbname, collection_data,
+            if dirpath:
+                testcase['dirpath']
+            results = run_validation_test(version, container, dbname, collection_data,
                                              testcase)
-            resultset.append(result_val)
+            resultset.extend(results)
     return resultset
 
 
@@ -210,7 +217,7 @@ def run_container_validation_tests_filesystem(container, snapshot_status=None):
                             ('masterTestId' in testcase and testcase['masterTestId'] == singletest):
                         newtestcases.append(testcase)
                 testset['cases'] = newtestcases
-        resultset = run_json_validation_tests(test_json_data, container, False, snapshot_status, dirpath=dirpath)
+        resultset = run_json_validation_tests(test_json_data, container, True, snapshot_status, dirpath=dirpath)
         if resultset:
             snapshot = test_json_data['snapshot'] if 'snapshot' in test_json_data else ''
             if singletest:
